/*  $Id: LineReaderBuffer.java 1335 2012-08-25 13:27:49Z sdevaux $
 *
 * Tabs = 4 chars
 * copyright (C) 2002-2012 Sebastien Devaux
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 *
 *              Sebastien Devaux <sebastien.devaux@laposte.net>
 */
package net.eduvax.util;

import java.io.BufferedReader;
import java.io.FileInputStream;
import java.io.InputStreamReader;
import java.io.InputStream;
import java.io.IOException;

/** Lecture d'un flux ligne à ligne avec conservation de 
 * la dernière ligne lue 
 * <p>La conservation de la dernière ligne lue permet de moduler le
 * processus de lecture en fonction du contenu. Voir par exemple dans
 * CSortedStreamMerger comment on l'utilise pour comparer l'état de
 * plusieurs CLineReaderBuffer et les séléctionner.</p>
 */ 
public class LineReaderBuffer
{
    /** Création d'un nouveau lecteur ligne à ligne bufferisé
     * 
     * @param input source des données
     */ 
    public LineReaderBuffer(InputStream input) 
    {
        _reader=new BufferedReader(new InputStreamReader(input));
    }
    /** Création d'un nouveau lecteur ligne à ligne bufferisé
     * 
     * @param path chemin du fichier à lire
     */ 
    public LineReaderBuffer(String path) throws IOException 
    {
        _reader=new BufferedReader(new InputStreamReader(
                                    new FileInputStream(path)));
    }
    /** Lire la ligne suivante 
     * @return 
     * - la ligne de texte lue.
     * - null s'il n'y a plus rien à lire.
     * @return 
     */ 
    public String readNext() throws IOException
    {
        _lastLine=_reader.readLine();
        return _lastLine;
    }
    /** Obtenir la dernière ligne lue mémorisée 
     * <p>N'affecte pas l'avancement de la lecture de la source de donnée.
     * </p>
     * @return 
     * - la dernière ligne lue.
     * - null si rien n'a encore été lu ou si tout a été déjà lu.
     */ 
    public String peek()
    {
        return _lastLine;
    }
    /** Fermer le flux */
    public void close() throws IOException {
        _reader.close();
    }
    /** Dernière ligne lue */
    private String _lastLine;
    /** Source de données */
    private BufferedReader _reader;
}
